==> ikaaro-0.50.0.tar.gz: ikaaro-0.50.0/ui/tiny_mce/plugins/advimage/langs/ja_dlg.js <==
tinyMCE.addI18n('ja.advimage_dlg',{
tab_general:"\u4E00\u822C",
tab_appearance:"\u8868\u793A",
tab_advanced:"\u4E0A\u7D1A\u8005\u5411\u3051",
general:"\u4E00\u822C",
title:"\u30BF\u30A4\u30C8\u30EB",
preview:"\u30D7\u30EC\u30D3\u30E5\u30FC",
constrain_proportions:"\u7E26\u6A2A\u6BD4\u306E\u4FDD\u5B58",
langdir:"\u6587\u7AE0\u306E\u65B9\u5411",
langcode:"\u8A00\u8A9E\u30B3\u30FC\u30C9",
long_desc:"\u8A73\u7D30\u8AAC\u660E\u30EA\u30F3\u30AF",
style:"\u30B9\u30BF\u30A4\u30EB",
classes:"\u30AF\u30E9\u30B9",
ltr:"\u5DE6\u304B\u3089\u53F3",
rtl:"\u53F3\u304B\u3089\u5DE6",
id:"Id",
map:"\u30A4\u30E1\u30FC\u30B8\u30DE\u30C3\u30D7",
swap_image:"\u30ED\u30FC\u30EB\u30AA\u30FC\u30D0\u30FC\u52B9\u679C",
alt_image:"\u753B\u50CF\u5207\u66FF\u3092\u884C\u3046",
mouseover:"\u30DE\u30A6\u30B9\u30AA\u30FC\u30D0\u30FC\u6642",
mouseout:"\u30DE\u30A6\u30B9\u30A2\u30A6\u30C8\u6642",
misc:"\u305D\u306E\u4ED6",
example_img:"Appearance preview image",
missing_alt:"\u753B\u50CF\u306E\u8AAC\u660E\u6587\u304C\u5165\u529B\u3055\u308C\u3066\u3044\u307E\u305B\u3093\u3002\u76EE\u306E\u4E0D\u81EA\u7531\u306A\u65B9\u3084\u30C6\u30AD\u30B9\u30C8\u30D6\u30E9\u30A6\u30B6\u3092\u5229\u7528\u3055\u308C\u3066\u3044\u308B\u65B9\u3078\u914D\u616E\u3057\u3001\u753B\u50CF\u8AAC\u660E\u3092\u5165\u529B\u3059\u308B\u3053\u3068\u3092\u304A\u85A6\u3081\u3057\u307E\u3059\u3002",
dialog_title:"\u753B\u50CF\u306E\u633F\u5165/\u7DE8\u96C6",
src:"\u753B\u50CFURL",
alt:"\u753B\u50CF\u306E\u8AAC\u660E",
list:"\u4E00\u89A7\u304B\u3089\u9078\u3076",
border:"\u67A0\u7DDA",
dimensions:"\u30B5\u30A4\u30BA",
vspace:"\u4E0A\u4E0B\u4F59\u767D",
hspace:"\u5DE6\u53F3\u4F59\u767D",
align:"\u914D\u7F6E",
align_baseline:"Baseline",
align_top:"Top",
align_middle:"Middle",
align_bottom:"Bottom",
align_texttop:"Text top",
align_textbottom:"Text bottom",
align_left:"Left",
align_right:"Right",
image_list:"\u4E00\u89A7\u304B\u3089\u9078\u3076"
});

==> ikaaro-0.61.4.tar.gz: ikaaro-0.61.4/ui/tiny_mce/plugins/advimage/langs/ja_dlg.js <==
tinyMCE.addI18n('ja.advimage_dlg',{
tab_general:"\u4E00\u822C",
tab_appearance:"\u8868\u793A",
tab_advanced:"\u4E0A\u7D1A\u8005\u5411\u3051",
general:"\u4E00\u822C",
title:"title\u5C5E\u6027",
preview:"\u30D7\u30EC\u30D3\u30E5\u30FC",
constrain_proportions:"\u7E26\u6A2A\u6BD4\u306E\u4FDD\u5B58",
langdir:"\u6587\u7AE0\u306E\u65B9\u5411",
langcode:"\u8A00\u8A9E\u30B3\u30FC\u30C9",
long_desc:"\u8A73\u7D30\u8AAC\u660E\u30EA\u30F3\u30AF",
style:"style\u5C5E\u6027",
classes:"class\u5C5E\u6027",
ltr:"\u5DE6\u304B\u3089\u53F3",
rtl:"\u53F3\u304B\u3089\u5DE6",
id:"ID\u5C5E\u6027",
map:"\u30A4\u30E1\u30FC\u30B8\u30DE\u30C3\u30D7",
swap_image:"\u30ED\u30FC\u30EB\u30AA\u30FC\u30D0\u30FC\u52B9\u679C",
alt_image:"\u753B\u50CF\u5207\u66FF\u3092\u884C\u3046",
mouseover:"\u30DE\u30A6\u30B9\u30AA\u30FC\u30D0\u30FC\u6642",
mouseout:"\u30DE\u30A6\u30B9\u30A2\u30A6\u30C8\u6642",
misc:"\u305D\u306E\u4ED6",
example_img:"Appearance preview image",
missing_alt:"\u753B\u50CF\u306E\u8AAC\u660E\u6587\u304C\u5165\u529B\u3055\u308C\u3066\u3044\u307E\u305B\u3093\u3002\u76EE\u306E\u4E0D\u81EA\u7531\u306A\u65B9\u3084\u30C6\u30AD\u30B9\u30C8\u30D6\u30E9\u30A6\u30B6\u3092\u5229\u7528\u3055\u308C\u3066\u3044\u308B\u65B9\u3078\u914D\u616E\u3057\u3001\u753B\u50CF\u8AAC\u660E\u3092\u5165\u529B\u3059\u308B\u3053\u3068\u3092\u304A\u85A6\u3081\u3057\u307E\u3059\u3002",
dialog_title:"\u753B\u50CF\u306E\u633F\u5165/\u7DE8\u96C6",
src:"\u753B\u50CFURL",
alt:"alt\u5C5E\u6027",
list:"\u4E00\u89A7\u304B\u3089\u9078\u3076",
border:"\u67A0\u7DDA",
dimensions:"\u30B5\u30A4\u30BA",
vspace:"\u4E0A\u4E0B\u4F59\u767D",
hspace:"\u5DE6\u53F3\u4F59\u767D",
align:"\u914D\u7F6E",
align_baseline:"Baseline",
align_top:"Top",
align_middle:"Middle",
align_bottom:"Bottom",
align_texttop:"Text top",
align_textbottom:"Text bottom",
align_left:"Left",
align_right:"Right",
image_list:"\u4E00\u89A7\u304B\u3089\u9078\u3076"
});
